@@ -1,3 +1,14 @@
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
+ * All rights reserved.                                                      *
+ *                                                                           *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
+ * terms governing use, modification, and redistribution, is contained in    *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
+ * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /* H5pubconf.h */
 
 #ifndef H5_CONFIG_H_
@@ -26,7 +37,8 @@
 /* Define if building universal (internal helper macro) */
 /* #undef H5_AC_APPLE_UNIVERSAL_BUILD */
 
-/* Define if the memory buffers being written to disk should be cleared before writing. */
+/* Define if the memory buffers being written to disk should be cleared before
+   writing. */
 #define H5_CLEAR_MEMORY 1
 
 /* Define if C++ compiler recognizes offsetof */
@@ -507,8 +519,7 @@
    with special algorithm. */
 /* #undef H5_LONG_TO_LDOUBLE_SPECIAL */
 
-/* Define to the sub-directory in which libtool stores uninstalled libraries.
-   */
+/* Define to the sub-directory where libtool stores uninstalled libraries. */
 #if defined(__gnu_linux__)
 #define H5_LT_OBJDIR ".libs/"
 #endif
@@ -532,7 +543,7 @@
 #define H5_PACKAGE_NAME "HDF5"
 
 /* Define to the full name and version of this package. */
-#define H5_PACKAGE_STRING "HDF5 1.8.17"
+#define H5_PACKAGE_STRING "HDF5 1.8.20"
 
 /* Define to the one symbol short name of this package. */
 #define H5_PACKAGE_TARNAME "hdf5"
@@ -541,7 +552,7 @@
 #define H5_PACKAGE_URL "http://www.hdfgroup.org"
 
 /* Define to the version of this package. */
-#define H5_PACKAGE_VERSION "1.8.17"
+#define H5_PACKAGE_VERSION "1.8.20"
 
 /* Width for printf() for type `long long' or `__int64', use `ll' */
 #if defined(_WIN32)
@@ -754,7 +765,7 @@
 /* #undef H5_USING_MEMCHECKER */
 
 /* Version number of package */
-#define H5_VERSION "1.8.17"
+#define H5_VERSION "1.8.19"
 
 /* Data accuracy is prefered to speed during data conversions */
 #define H5_WANT_DATA_ACCURACY 1
